﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Configuration;
using System.ServiceModel.Channels;
using System.ServiceModel;
using System.Security.Authentication;
using System.Net;

namespace GetAuthreturnServiceInfo
{
    class GetAuthreturnServiceinfo
    {
        //TLS 1.2 support for .NET 3.5
        public const SslProtocols _Tls12 = (SslProtocols)0x00000C00;
        public const SecurityProtocolType Tls12 = (SecurityProtocolType)_Tls12;

        static void Main(string[] args)
        {
            ServicePointManager.SecurityProtocol = Tls12;

            // Your username, password and customer number are imported from the following file
            // CPCWS_SOAP_Shipping_DotNet_Samples\SOAP\shipping\user.xml 
            var username = ConfigurationSettings.AppSettings["username"];
            var password = ConfigurationSettings.AppSettings["password"];
            var mailedBy = ConfigurationSettings.AppSettings["customerNumber"];
            ServiceInfoPortTypeClient server = new ServiceInfoPortTypeClient("ServiceInfoPort", "https://ct.soa-gw.canadapost.ca/rs/soap/serviceinfo/v2");

            server.ClientCredentials.UserName.UserName = username;
            server.ClientCredentials.UserName.Password = password;

            // Create Request
            ServiceinfoRequestType serviceInfoReq = new ServiceinfoRequestType();

            // Disable timestamp on request
            BindingElementCollection elements = server.Endpoint.Binding.CreateBindingElements();
            elements.Find<SecurityBindingElement>().IncludeTimestamp = false;
            server.Endpoint.Binding = new CustomBinding(elements);

            String responseAsString = "";

            try
            {
                // Execute Request
                ServiceinfoResponseType response = server.GetShipmentServiceInfo(serviceInfoReq);

                // Retrieve values from response object
                if (response.Item.GetType() == typeof(InfoMessagesType))
                {
                    InfoMessagesType infoMessages = (InfoMessagesType)response.Item;
                    if (infoMessages.infomessage != null)
                    {
                        foreach (InfoMessageType infoMessage in infoMessages.infomessage)
                        {
                            responseAsString += " Message Type is :" + infoMessage.messagetype + "\r\n";
                            responseAsString += " Message Text is :" + infoMessage.messagetext + "\r\n";
                            responseAsString += " Message Start Time is :" + infoMessage.fromdatetime + "\r\n";
                            responseAsString += " Message End Time is :" + infoMessage.todatetime + "\r\n";
                        }
                    }
                    
                }
                else
                {
                    messages msgs = (messages)response.Item;
                    foreach (var item in msgs.message)
                    {
                        responseAsString += "Error Code: " + item.code + "\r\n";
                        responseAsString += "Error Msg: " + item.description + "\r\n";
                    }
                }
            }
            catch (FaultException faultEx)
            {
                // SOAP Fault
                responseAsString += "Fault Code: " + faultEx.Code.Name + "\r\n";
                responseAsString += "Fault String: " + faultEx.Message + "\r\n";
            }
            catch (Exception ex)
            {
                // Misc Exception
                responseAsString += "ERROR: " + ex.Message + "\r\n";
            }

            Console.WriteLine(responseAsString);
            Console.WriteLine("Press any key to continue...");
            Console.ReadKey(true);

        }
    }
}
